DeadCode Module
Types
| Type | Description |
|
Result of dead code analysis containing total, reachable, and unreachable symbol counts. |
|
|
|
|
|
|
|
|
|
Functions and values
| Function or value |
Description
|
Full Usage:
findDeadCode allSymbols reachable testMethodNames includeTests
Parameters:
SymbolInfo list
reachable : Set<string>
testMethodNames : Set<string>
includeTests : bool
Returns: DeadCodeResult * AnalysisEvent list
|
Find symbols that are not reachable from the given entry point patterns.
|
Full Usage:
findDeadCodeVerbose allSymbols reachable testMethodNames includeTests getIncomingEdgesBatch
Parameters:
SymbolInfo list
reachable : Set<string>
testMethodNames : Set<string>
includeTests : bool
getIncomingEdgesBatch : string list -> Map<string, string list>
Returns: VerboseDeadCodeResult * AnalysisEvent list
|
Find dead code with verbose reasons for why each symbol is unreachable.
|
Full Usage:
findEntryPoints allNames entryPointPatterns
Parameters:
Set<string>
entryPointPatterns : string list
Returns: string list
|
Match entry point patterns against all symbol names and return the matching names.
|
TestPrune